# Launch the process once the param window is validated
def test_unaryunion(self):

    # Variables to test
    lfp_lyr = "PolygonToLineLayer"
    lfp_atts = ["ID"]
    lfp_atts_qt = [QVariant.Int]
    fnc_title_txt = "Création des zones de contraintes avec notations agrégées"
    end_fnc_txt = "Création de la nouvelle couche terminée"
    
    # Find the project path
    prjfi = QFileInfo(QgsProject.instance().fileName())
    prj_filepath = prjfi.absolutePath()
    prj_docpath = os.path.dirname(prj_filepath)
    
    # Layer to process
    lyr_extract1 = get_map_layer_by_name("PolygonToLineLayer0-limited3", self.map_layer_registry)
    lines_geoms = [obj.geometry() for obj in lyr_extract1.getFeatures()]

    # Process unaryUnionLayer to process
    nw_geom_un = [QgsGeometry.unaryUnion(lines_geoms)]
    
    # Create a shapefile to see the result of unary union
    lfp3_shp_fname = os.path.join(prj_filepath, (lfp_lyr + "-unary.shp"))
    lfp3_file = self.create_shp(lfp3_shp_fname, QgsWkbTypes.LineString, 
                                    srid_nwlyr, lfp_atts, lfp_atts_qt)
    obj_id = 0
    for obj_un in nw_geom_un:
        multiGeom = QgsGeometry()
        nw_geom_un_sg = []
        if obj_un.isMultipart():
            multiGeom = obj_un.asMultiPolyline()
            for i in multiGeom:
                nw_geom_un_sg.append(QgsGeometry().fromPolylineXY(i))
        else:
            nw_geom_un_sg.append(obj_un)
        for geom_sg in nw_geom_un_sg:
            nw_atts_val = []
            nw_atts_val.append(obj_id)
            obj_id += 1
            nw_feat = QgsFeature()
            nw_feat.setAttributes(nw_atts_val)
            nw_feat.setGeometry(geom_sg)
            # Case of wrong object
            if not lfp3_file.addFeature(nw_feat):
                QMessageBox.information(self.iface.mainWindow(), fnc_title_txt, "Mauvaise géométrie")
    del lfp3_file
    
    nw_geom_pol = QgsGeometry.polygonize(nw_geom_un)

    nw_geom_col = nw_geom_pol.asGeometryCollection()
    
    # Create a shapefile to see the result of polygonize
    lfp4_shp_fname = os.path.join(prj_filepath, (lfp_lyr + "4.shp"))
    lfp4_file = self.create_shp(lfp4_shp_fname, QgsWkbTypes.MultiPolygon, 
                                    srid_nwlyr, lfp_atts, lfp_atts_qt)
    obj_id = 0
    for obj_col in nw_geom_col:
        obj_col.convertGeometryCollectionToSubclass(QgsWkbTypes.PolygonGeometry )
        nw_atts_val = []
        nw_atts_val.append(obj_id)
        obj_id += 1
        nw_feat = QgsFeature()
        nw_feat.setAttributes(nw_atts_val)
        nw_feat.setGeometry(obj_col)
        # Case of wrong object
        if not lfp4_file.addFeature(nw_feat):
            QMessageBox.information(self.iface.mainWindow(), fnc_title_txt, "Mauvaise géométrie")
    del lfp4_file
    # >>>
    
    QMessageBox.information(self.iface.mainWindow(), fnc_title_txt, end_fnc_txt)
        
            
# Create shapefile with required fields
# Returns new file
# file_name = string containing file name with its complete path
# shp_type = wkbtype (QgsWkbTypes.MultiPolygon, QgsWkbTypes.MultiLineString, ...) 
# srid = srid (integer)
# shp_fields = list of fields' name
# fields_type = list of fields' type associated to each field (QVariant, ...)
#               in the same order of shp_fields
def create_shp(self, file_name, shp_type, srid, shp_fields, fields_type):  
    crs = QgsCoordinateReferenceSystem()
    crs.createFromSrid(srid)
    nw_flds = QgsFields()
    for idx, att in enumerate(shp_fields):
        nw_fld = QgsField(att, fields_type[idx])
        if fields_type[idx] == QVariant.Double:
            nw_fld.setLength(10)
            nw_fld.setPrecision(2)
        nw_flds.append(nw_fld)
    nw_file = QgsVectorFileWriter(file_name, "utf-8", nw_flds, shp_type, crs, "ESRI Shapefile")
    if (nw_file.hasError() != QgsVectorFileWriter.NoError):
        QMessageBox.critical(self.iface.mainWindow(), fnc_title_txt, crea_imp_txt + str(nw_file.errorMessage())) 
        return None
    else:
        return nw_file